/*
 * Copyright (C) 2010-2011 Andre Noll <maan@systemlinux.org>
 *
 * Licensed under the GPL v2. For licencing details see COPYING.
 */

/**
 * \file ogg_afh_common.h Structures and prototypes common to audio format
 * handlers that use the ogg container format.
 */

/**
 * Callback structure provided by vorbis/speex audio format handlers.
 *
 * Both audio formats utilize the ogg container format. Meta info about
 * the audio file is contained in the first three ogg packets.
 */
struct ogg_afh_callback_info {
 	/**
	  * ogg_get_file_info() calls this function for each of the three
	  * header packets. If this callback returns a negative value, the
	  * audio file is considered invalid and the chunk table is not
	  * created. If it returns zero, the end of the header has been
	  * reached and no further ogg packets should be processed.
	  */
	int (*packet_callback)(ogg_packet *packet, int packet_num,
		int serial, struct afh_info *afhi, void *private_data);
	/** Vorbis/speex specific data. */
	void *private_data;
};

int ogg_get_file_info(char *map, size_t numbytes, struct afh_info *afhi,
		struct ogg_afh_callback_info *ci);
